import React, { useState, useRef, useEffect } from "react";
import { Form, Input, Button, Space, Table, Menu, Image } from "antd";
import {
  Routes,
  Route,
  Navigate,
  useNavigate,
  useLocation,
} from "react-router-dom";
import baseRequest from "../../utils/baseRequest";

const PostMachineReviewContent = (props) => {
  const { TextArea } = Input;
  const current = props.current;
  //表头
  const columns = [
    {
      title: "现内容",
      dataIndex: "newMedia",
      key: "newMedia",
      render: (data) => (
        <div className="flex flex-col">
          <div>
            <p className="text-red-400">
              文案：<span className="text-black">{data.text}</span>
            </p>
          </div>
          <p className="text-red-400">媒体：</p>
          <div className="flex flex-wrap gap-1">
            {data.media.images.map((item, index) => (
              <Image key={index} src={item.urls[0]} width={100} />
            ))}
            {data.media.videos.map((item, index) => (
              <video key={index} src={item.urls[0]} width={150} controls />
            ))}
          </div>
        </div>
      ),
    },
    {
      title: "原内容",
      dataIndex: "oldMedia",
      key: "oldMedia",
      render: (data) => (
        <div className="flex flex-col">
          <p className="text-red-400">
            文案：<span className="text-black">{data.text}</span>
          </p>
          <p className="text-red-400">媒体：</p>
          <div className="flex flex-wrap gap-1">
            {data.media.images.map((item, index) => (
              <Image key={index} src={item.urls[0]} width={100} />
            ))}
            {data.media.videos.map((item, index) => (
              <video key={index} src={item.urls[0]} width={150} controls />
            ))}
          </div>
        </div>
      ),
    },
    {
      title: "审核结果",
      dataIndex: "info",
      key: "info",
      render: (data) => (
        <div className="flex flex-col">
          <p>文案审核结果：</p>
          <div>
            {data.text.status === 2 || data.text.status === 5 ? (
              <p className="text-green-400">无违规</p>
            ) : (
              <div className="flex flex-wrap gap-1">
                {data.text.spam_label_details && (
                  <div className="border-2 border-black bg-gray-200">
                    <p>垃圾审核：</p>
                    <ul>
                      {data.text.spam_label_details?.map((item, index) => (
                        <li key={index}>{item}</li>
                      ))}
                    </ul>
                  </div>
                )}
                {data.text.politics_label_details && (
                  <div className="border-2 border-black bg-gray-200">
                    <p>敏感审核：</p>
                    <ul>
                      {data.text.politics_label_details?.map((item, index) => (
                        <li key={index}>{item}</li>
                      ))}
                    </ul>
                  </div>
                )}
                {data.text.abuse_label_details && (
                  <div className="border-2 border-black bg-gray-200">
                    <p>辱骂审核：</p>
                    <ul>
                      {data.text.abuse_label_details?.map((item, index) => (
                        <li key={index}>{item}</li>
                      ))}
                    </ul>
                  </div>
                )}
                {data.text.terrorism_label_details && (
                  <div className="border-2 border-black bg-gray-200">
                    <p>暴恐审核：</p>
                    <ul>
                      {data.text.terrorism_label_details?.map((item, index) => (
                        <li key={index}>{item}</li>
                      ))}
                    </ul>
                  </div>
                )}
                {data.text.porn_label_details && (
                  <div className="border-2 border-black bg-gray-200">
                    <p>鉴黄审核：</p>
                    <ul>
                      {data.porn_label_details?.map((item, index) => (
                        <li key={index}>{item}</li>
                      ))}
                    </ul>
                  </div>
                )}
                {data.text.flood_label_details && (
                  <div className="border-2 border-black bg-gray-200">
                    <p>灌水审核：</p>
                    <ul>
                      {data.text.flood_label_details?.map((item, index) => (
                        <li key={index}>{item}</li>
                      ))}
                    </ul>
                  </div>
                )}
                {data.text.contraband_label_details && (
                  <div className="border-2 border-black bg-gray-200">
                    <p>违禁审核：</p>
                    <ul>
                      {data.text.contraband_label_details?.map(
                        (item, index) => (
                          <li key={index}>{item}</li>
                        )
                      )}
                    </ul>
                  </div>
                )}
              </div>
            )}
          </div>
          <hr className="w-full" />
          <p>媒体审核结果：</p>
          {data.media === null && (
            <p className="text-green-400">视频不过审核</p>
          )}
          <div>
            {data.media?.map((item, index) => {
              if (item.status === 2 || item.status === 5) {
                return (
                  <p key={index} className="text-green-400">
                    图{index + 1}无违规
                  </p>
                );
              }
              if (item.status === 10) {
                return (
                  <p key={index} className="text-green-400">
                    图{index + 1}审核失败
                  </p>
                );
              }
              return (
                <div key={index}>
                  <p className="text-red-400">图{index + 1}违规情况：</p>
                  <div className="flex flex-wrap gap-1">
                    {item.porn_scene_suggestion !== "pass" && (
                      <div className="border-2 border-black bg-gray-200">
                        <p>色情审核：</p>
                        <ul>
                          <li>建议：{item.porn_scene_suggestion}</li>
                          <li>结果：{item.porn_scene_label}</li>
                          <li>结果：{item.porn_scene_rate.toFixed(1)}</li>
                        </ul>
                      </div>
                    )}
                    {item.terrorism_scene_suggestion !== "pass" && (
                      <div className="border-2 border-black bg-gray-200">
                        <p>暴恐审核：</p>
                        <ul>
                          <li>建议：{item.terrorism_scene_suggestion}</li>
                          <li>结果：{item.terrorism_scene_label}</li>
                          <li>结果：{item.terrorism_scene_rate.toFixed(1)}</li>
                        </ul>
                      </div>
                    )}
                    {item.live_scene_suggestion !== "pass" && (
                      <div className="border-2 border-black bg-gray-200">
                        <p>不良审核：</p>
                        <ul>
                          <li>建议：{item.live_scene_suggestion}</li>
                          <li>结果：{item.live_scene_label}</li>
                          <li>结果：{item.live_scene_rate.toFixed(1)}</li>
                        </ul>
                      </div>
                    )}
                  </div>
                </div>
              );
            })}
          </div>
        </div>
      ),
    },
    {
      title: "提交时间",
      dataIndex: "submitTime",
      key: "submitTime",
    },
    {
      title: "备注",
      dataIndex: "remarks",
      key: "remarks",
      render: (_, record) => (
        <div className="flex flex-col">
          <Form.Item
            name={record.id.text}
            initialValue={`文案：${record.remarks.text}`}
          >
            <TextArea disabled rows={4} />
          </Form.Item>
          <Form.Item
            name={record.id.media}
            initialValue={`媒体：${record.remarks.media}`}
          >
            <TextArea disabled rows={4} />
          </Form.Item>
        </div>
      ),
    },
    {
      title: "操作",
      dataIndex: "opeartion",
      key: "opeartion",
      render: (_, record) => (
        <div>
          <Space>
            <Space.Compact direction="vertical">
              {(current === "rollbackbymachine" ||
                current === "machinereviewfail") && (
                <Button type="primary" onClick={() => onClickSubmit(record)}>
                  通过
                </Button>
              )}
            </Space.Compact>
          </Space>
        </div>
      ),
    },
  ];
  //给表单绑定ref
  const formRef = useRef(null);
  //点击修改状态按钮
  const onClickSubmit = (record) => {
    formRef.current.record = record;
    formRef.current.btn = "submit";
    formRef.current.submit();
  };
  //提交表单
  const handleSubmit = async () => {
    try {
      //通过图片审核，如果是视频直接跳过
      const base = baseRequest();
      if (formRef.current.record.others.media.id !== undefined) {
        const response = await fetch("/op/image_audit_task/pass_batch", {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify({
            tasks: [formRef.current.record.others.media],
            ...base,
          }),
        });
        const approveData = await response.json();
        console.log(approveData);
        if (approveData.ret === -1) {
          alert(approveData.msg);
          return;
        }
      }
      //通过文案审核
      const response2 = await fetch("/op/text_audit_task/pass_batch", {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          tasks: [formRef.current.record.others.text],
          ...base,
        }),
      });
      const approveData2 = await response2.json();
      console.log(approveData2);
      if (approveData2.ret === -1) {
        alert(approveData2.msg);
        return;
      }
      //取消数据展示
      setShowData(
        showData.filter(
          (item) => item.id.media !== formRef.current.record.others.media.id
        )
      );
    } catch (error) {
      console.error(error);
    }
  };
  //获取数据
  const [data, setData] = useState([]);
  const [offset, setOffset] = useState(0);
  const [more, setMore] = useState(1);
  const getData = async () => {
    if (!more) return;
    let querryStatus;
    switch (current) {
      case "rollbackbymachine":
        querryStatus = 4;
        break;
      case "machinereviewfail":
        querryStatus = 10;
        break;
      case "passbymachine":
        querryStatus = 2;
        break;
      case "passbyoperator":
        querryStatus = 5;
        break;
      default:
        break;
    }
    try {
      const base = baseRequest();
      const response = await fetch("/op/moment_audit_task/list", {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          status: querryStatus,
          offset: offset,
          limit: 200,
          ...base,
        }),
      });
      const temData = await response.json();
      console.log(temData);
      if (temData.ret === -1) {
        alert(temData.msg);
        return;
      }
      //匹配表格格式
      const structedData = temData.data.list.map((item, index) => {
        return {
          key: index,
          id: {
            media: item.image_audit_task_vo.id,
            text: item.text_audit_task_vo.id,
          },
          newMedia: {
            media: item.moment_audit_task.final_media
              ? item.moment_audit_task.final_media
              : item.moment_audit_task.audited_media,
            text: item.moment_audit_task.final_text
              ? item.moment_audit_task.final_text
              : item.moment_audit_task.audited_text,
          },
          oldMedia: {
            media: item.moment_audit_task.audited_media,
            text: item.moment_audit_task.audited_text,
          },
          info: {
            media: item.image_audit_task_vo.image_audits,
            text: item.text_audit_task_vo.text_audit,
          },
          submitTime: new Date(
            item.moment_audit_task.ct * 1000
          ).toLocaleString(),
          remarks: {
            media: item.image_audit_task_vo.remarks,
            text: item.text_audit_task_vo.remarks,
          },
          others: {
            media: {
              id: item.image_audit_task_vo.id,
              audited_media: item.image_audit_task_vo.audited_media,
              associative_database:
                item.image_audit_task_vo.associative_database,
              associative_table_name:
                item.image_audit_task_vo.associative_table_name,
              associative_table_id:
                item.image_audit_task_vo.associative_table_id,
              associative_table_column:
                item.image_audit_task_vo.associative_table_column,
            },
            text: {
              id: item.text_audit_task_vo.id,
              audited_text: item.text_audit_task_vo.audited_text,
              associative_database:
                item.text_audit_task_vo.associative_database,
              associative_table_name:
                item.text_audit_task_vo.associative_table_name,
              associative_table_id:
                item.text_audit_task_vo.associative_table_id,
              associative_table_column:
                item.text_audit_task_vo.associative_table_column,
            },
          },
        };
      });
      setData([...data, ...structedData]);
      setOffset(temData.data.offset);
      setMore(temData.data.more);
    } catch (error) {
      console.error(error);
    }
  };
  useEffect(() => {
    getData();
  }, [current]);

  //展示的数据
  const [showData, setShowData] = useState([]);
  useEffect(() => {
    setShowData(data);
  }, [data]);
  //表单提交失败
  const onFinishFailed = (errorInfo) => {
    console.log("Failed:", errorInfo);
  };
  return (
    <div style={{ marginLeft: 20, marginRight: 20 }}>
      <p>
        {current === "rollbackbymachine" && `机审核违规${showData.length}条`}
        {current === "passbymachine" && `机审核通过${showData.length}条`}
        {current === "passbyoperator" && `运营通过${showData.length}条`}
      </p>
      <Form
        ref={formRef}
        name="remarks"
        onFinish={handleSubmit}
        onFinishFailed={onFinishFailed}
      >
        <Table
          columns={columns}
          dataSource={showData}
          pagination={{ pageSize: 20 }}
          scroll={{ y: window.innerHeight - 300 }}
        />
      </Form>
    </div>
  );
};

export default function PostMachineReview() {
  const navigate = useNavigate();
  //当前tab
  const location = useLocation();
  const pathname = location.pathname.split("/")[2] || "rollbackbymachine";
  const [current, setCurrent] = useState(pathname);
  //tab名称
  const items = [
    {
      label: "机审回退",
      key: "rollbackbymachine",
    },
    {
      label: "机审失败",
      key: "machinereviewfail",
    },
    {
      label: "机审通过",
      key: "passbymachine",
    },
    {
      label: "运营通过",
      key: "passbyoperator",
    },
  ];
  const onClick = (e) => {
    setCurrent(e.key);
    navigate(e.key);
    window.location.reload();
  };

  return (
    <div>
      <Menu
        onClick={onClick}
        selectedKeys={[current]}
        mode="horizontal"
        items={items}
      />
      <Routes>
        <Route
          path="/"
          element={<Navigate to="/postMachineReview/rollbackbymachine" />}
        />
        <Route
          path="/rollbackbymachine"
          element={<PostMachineReviewContent current="rollbackbymachine" />}
        />
        <Route
          path="/machinereviewfail"
          element={<PostMachineReviewContent current="machinereviewfail" />}
        />
        <Route
          path="/passbymachine"
          element={<PostMachineReviewContent current="passbymachine" />}
        />
        <Route
          path="/passbyoperator"
          element={<PostMachineReviewContent current="passbyoperator" />}
        />
      </Routes>
    </div>
  );
}
